@@ -672,7 +672,7 @@ uint32_t coff_construct_image(const char *coff_file, uint16_t buf[], uint32_t bu
     uint16_t	flags; 		// flags for this section
     uint32_t	dest_address;   // destination address
     uint32_t 	high_address;	// highest address of section
-    uint32_t 	length;		// length of codewords
+//  uint32_t 	length;		// length of codewords
     uint16_t	rec_size;	// init record length in words
     uint32_t	bss_addr;	// init record dest address
     uint16_t	b[B_LEN];
@@ -793,8 +793,7 @@ uint32_t coff_construct_image(const char *coff_file, uint16_t buf[], uint32_t bu
     assert(high_address < buf_len);
 
     // determine length of the block to be boot loaded  
-
-    length = high_address-dest_address;
+    // length = high_address-dest_address;
 
     // move block up to make space for dest and length words
 
