@@ -84,14 +84,19 @@
 #endif
 
 
+#include <linux/version.h>
+
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33))
+ #include <generated/autoconf.h>
+#else
+ #include <linux/autoconf.h>
+#endif
 
 // Module version boilerplate
-#include <linux/autoconf.h>
 #if defined( CONFIG_MODVERSIONS) && !defined(MODVERSIONS)
 #define MODVERSIONS
 #endif
 
-#include <linux/version.h>
 #ifdef MODVERSIONS
 #if (LINUX_VERSION_CODE > KERNEL_VERSION(2,6,4))
 #include <config/modversions.h>
@@ -145,7 +150,7 @@ unsigned int major = 0;
 
 static int vpb_open( struct inode*, struct file* );
 static int vpb_release( struct inode*, struct file* );
-static int vpb_ioctl( struct inode*, struct file*, unsigned int, unsigned long );
+static long vpb_ioctl(struct file*, unsigned int, unsigned long);
 
 void card_detail(int pci_n);
 unsigned int eeread(int PCIn, int addr);
@@ -179,15 +184,15 @@ char iicin(int PCInn, int sig);
 #endif
 
 static struct file_operations vpb_fops={
-	.owner   = THIS_MODULE,
-	.llseek  = NULL,
-	.read    = NULL,
-	.write   = NULL,
-	.poll    = NULL,
-	.ioctl   = vpb_ioctl,
-	.open    = vpb_open,
-	.release = vpb_release,
-	.fasync  = NULL
+	.owner		= THIS_MODULE,
+	.llseek		= NULL,
+	.read		= NULL,
+	.write		= NULL,
+	.poll		= NULL,
+	.unlocked_ioctl	= vpb_ioctl,
+	.open		= vpb_open,
+	.release	= vpb_release,
+	.fasync		= NULL
 };
 
 // number of valid PCI devices detected
@@ -241,7 +246,7 @@ int init_module(void)
 	// search for V4PCI devices on PCI bus
 
 	numPCI = 0;
-	while((dev = pci_find_device(PCI_VENDOR_ID_PLX, PCI_DEVICE_ID_PLX_9050,
+	while((dev = pci_get_device(PCI_VENDOR_ID_PLX, PCI_DEVICE_ID_PLX_9050,
 				     dev)) != NULL) {
 
 		// check that subsytem ID & Subsytem Vendor matches
@@ -358,8 +363,8 @@ int init_module(void)
 
 	return 0;
 
-    hell:
-
+hell:
+	pci_dev_put(dev);
 	cleanup_module();
 	return ret;
 }
@@ -434,10 +439,7 @@ static int vpb_release( struct inode *inode, struct file *filep )
 
 \*--------------------------------------------------------------------------*/
 
-static int vpb_ioctl(struct inode *inode,
-		     struct file *filp,
-		     unsigned int cmd,
-		     unsigned long arg)
+static long vpb_ioctl(struct file *filp, unsigned int cmd, unsigned long arg)
 {
 	int      ret;
 	VPB_DATA vpb_data;  // ioctl parameters from user space
