@@ -130,7 +130,7 @@
 	while(cond){							    \
 	    udelay(delay);						    \
 	    if(++countvar > iter){					    \
-		dbginfo(4,card->cardnum,"busy wait failed at %d",__LINE__);\
+		cardwarn(card,"busy wait failed at %d",__LINE__);	    \
 		return failret;						    \
 	    }								    \
 	}								    \
@@ -141,7 +141,7 @@
 	while(cond){							    \
 	    udelay(delay);						    \
 	    if(++countvar > iter){					    \
-		dbginfo(4,card->cardnum,"busy wait failed at %d",__LINE__);\
+		cardwarn(card,"busy wait failed at %d",__LINE__);	    \
 		spin_unlock_irqrestore(&card->lock, flags);		    \
 		return failret;						    \
 	    }								    \
@@ -235,16 +235,33 @@ DEFINE_MUTEX(cards_mutex);
 
 const unsigned char fxo_port_lookup[8] = {0x0, 0x8, 0x4, 0xc, 0x10, 0x18, 0x14, 0x1c};
 const unsigned char fxs_port_lookup[8] = {0x0, 0x1, 0x2, 0x3, 0x10, 0x11, 0x12, 0x13};
-static const char   vtopenpci[]        = "OpenPCI";
+
+#define PCI_DEVICE_ID_VOICETRONIX_OPENPCI	PCI_ANY_ID
+#define PCI_DEVICE_ID_VOICETRONIX_OPENPCIE	0x0002
 
 static struct pci_device_id openpci_idtable[] = {
-	{ PCI_VENDOR_ID_TIGERJET,    PCI_DEVICE_ID_TIGERJET_300,
-	  PCI_VENDOR_ID_VOICETRONIX, PCI_DEVICE_ID_VOICETRONIX_OPENPCI,
-	  0, 0, (kernel_ulong_t) &vtopenpci },
-	{ 0 }
+	{
+		.vendor		= PCI_VENDOR_ID_TIGERJET,
+		.device		= PCI_DEVICE_ID_TIGERJET_300,
+		.subvendor	= PCI_VENDOR_ID_VOICETRONIX,
+		.subdevice	= PCI_DEVICE_ID_VOICETRONIX_OPENPCIE,
+		.driver_data	= (kernel_ulong_t)"OpenPCIe",
+	}, {
+		.vendor		= PCI_VENDOR_ID_TIGERJET,
+		.device		= PCI_DEVICE_ID_TIGERJET_300,
+		.subvendor	= PCI_ANY_ID,
+		.subdevice	= PCI_DEVICE_ID_VOICETRONIX_OPENPCI,
+		.driver_data	= (kernel_ulong_t)"OpenPCI",
+	},
+	{}
 };
 MODULE_DEVICE_TABLE(pci, openpci_idtable);
 
+const char *get_pci_boardname(const struct pci_device_id *ent)
+{
+	return (const char*)ent->driver_data;
+}
+
 static int __devinit openpci_probe_board(struct pci_dev *pdev, const struct pci_device_id *ent);
 static void __devexit openpci_remove_board(struct pci_dev *pdev);
 
@@ -988,7 +1005,7 @@ static int send_hookflash(struct vtboard *board, int port, int duration)
 
 	msleep( duration );
 
-	return set_hook_state( card, port, HOOK_OFFHOOK );
+	return set_hook_state( card, port, HOOK_FASTOFF );
 } //}}}
 
 static int vtopenpci_set_hook(struct vtboard *board, int port, int hookstate)
@@ -1234,7 +1251,13 @@ static int vtopenpci_ioctl(struct vtboard *board, int port, unsigned int cmd, vo
 	    case VT_IOC_SETFLASH:
 		dbgport(4,card,port, "VT_IOC_SETFLASH 0x%x", length);
 
-		if( card->chans[port].porttype != VT_PORT_PROSLIC ) return -EINVAL;
+		switch (card->chans[port].porttype) {
+		case VT_PORT_PROSLIC:
+		case VT_PORT_VDAA:
+			break;
+		default:
+			return -EINVAL;
+		}
 
 		spin_lock_irqsave(&card->lock, flags);
 		outb(0x27,PIB(1));  ++card->armbout; HTXF_WAIT_LOCKED_RET(-EIO);
@@ -1636,8 +1659,9 @@ static int __get_arm_id(struct openpci *card, int field, char *value)
 
 static int check_arm(struct openpci *card)
 { //{{{
-	char model[ID_DATA_MAXSIZE+1] = { [0 ... ID_DATA_MAXSIZE] = 0 };
-	char date[ID_DATA_MAXSIZE+1]  = { [0 ... ID_DATA_MAXSIZE] = 0 };
+	char model[ID_DATA_MAXSIZE+1] = { 0 };
+	char date[ID_DATA_MAXSIZE+1]  = { 0 };
+	const char *pciname = NULL;
 	unsigned long flags;
 	int i=0, tmp=0;
 
@@ -1655,9 +1679,20 @@ static int check_arm(struct openpci *card)
 	if(i>1)	__ping_arm(card);
 
 	if( ! __get_arm_id(card, 0, model) )  goto hell;
-	sscanf(model, "OpenPCI8.%02d", &(card->firmware));
 	cardinfo(card->cardnum, "  model: %s", model);
 
+	if (sscanf(model, "OpenPCIe8.%02d", &card->firmware) == 1)
+		pciname = get_pci_boardname(&openpci_idtable[0]);
+	else if (sscanf(model, "OpenPCI8.%02d", &card->firmware) == 1)
+		pciname = get_pci_boardname(&openpci_idtable[1]);
+
+	/* If in doubt, trust the firmware ... */
+	if (pciname && card->board.name != pciname) {
+		cardwarn(card, "PCI id says board is %s, firmware says %s\n",
+						card->board.name, model);
+		card->board.name = pciname;
+	}
+
 	if( ! __get_arm_id(card, 1, date) )   goto hell;
 	cardinfo(card->cardnum, "   date: %s", date);
 
@@ -1734,6 +1769,11 @@ static void arm_event(struct openpci *card, unsigned char *msg)
 		mess[0] = DSP_LLOOP_NOBATT;
 		mess[1] = DSP_LOOP_NOBATT;
 		break;
+	    case DSP_LOOP_FLASH:
+		dbgport(3,card,msg[0],"Loop Flash");
+		mess[0] = DSP_LLOOP_FLASH;
+		mess[1] = DSP_LOOP_FLASH;
+		break;
 
 	    case DSP_CODEC_HKOFF:
 	    {
@@ -2131,7 +2171,7 @@ static irqreturn_t openpci_isr(int irq, void *dev_id)
 static void get_module_info( struct openpci *card )
 { //{{{
 	unsigned long flags;
-	char buf[VT_MOD_INFO_SIZE + 1] = { [0 ... VT_MOD_INFO_SIZE] = 0 };
+	char buf[VT_MOD_INFO_SIZE + 1] = { 0 };
 	int i = 0;
 
 	spin_lock_irqsave(&card->lock, flags);
@@ -2203,7 +2243,7 @@ static void export_module_info( struct openpci *card )
 
 		if( mod->type[0] != 'F' ) continue;
 		if( ! *modroot ) {
-			char  dirname[16] = { [0 ... 15] = 0 };
+			char  dirname[16] = { 0 };
 
 			snprintf(dirname, sizeof(dirname)-1, "module%d", i);
 			*modroot = proc_mkdir(dirname, card->board.procfs_root);
@@ -2228,7 +2268,7 @@ static void unexport_module_info( struct openpci *card )
 
 	if( ! card->board.procfs_root ) return;
 	for(; i < 2; ++i){
-		char  dirname[16] = { [0 ... 15] = 0 };
+		char  dirname[16] = { 0 };
 		struct proc_dir_entry *modroot = card->moduleinfo[i].procfs_root;
 
 		snprintf(dirname, sizeof(dirname)-1, "module%d", i);
@@ -2248,7 +2288,6 @@ static int vtopenpci_board_register( struct openpci *card )
 
 	/* Register with vtcore */
 	board->owner        = THIS_MODULE;
-	board->name         = vtopenpci;
 	board->maxports     = MAX_PORTS;
 	board->chans        = card->chans;
 	board->ioctl        = vtopenpci_ioctl;
@@ -2290,11 +2329,6 @@ static int __devinit openpci_probe_board(struct pci_dev *pdev,
 	int failret = -ENOMEM;
 	unsigned long flags;
 
-	if( ent->driver_data != (kernel_ulong_t)&vtopenpci )
-	{
-		info("Probe of non-OpenPCI card, ignoring.");
-		return -EINVAL;
-	}
 	card = kzalloc(sizeof(struct openpci), GFP_KERNEL);
 	if(!card) {
 		crit("FAILED to allocate memory for new card");
@@ -2317,6 +2351,7 @@ static int __devinit openpci_probe_board(struct pci_dev *pdev,
 	card->cardnum = cardnum;
 	card->dev     = pdev;
 	card->armbout = 0;
+	card->board.name = get_pci_boardname(ent);
 
     #if VERBOSE_TIMING
 	card->time_tj_last     = 0;
